==> haskell-jose-0.7.0.0-82-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-A04mtlzBHzEIFLhSGh3H5D
key: jose-0.7.0.0-A04mtlzBHzEIFLhSGh3H5D
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: 9ea5c8b4370e2bec3e3d318819a2cfbc
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.6.4/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-A04mtlzBHzEIFLhSGh3H5D
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-5z3HaEzpg6LIa4r5qSJGsL
    attoparsec-0.13.2.2-EiCOeTjO227AS8aig3dZEf base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    bytestring-0.10.8.2 concise-0.1.0.1-AR833G6ogXNIHVnTYCxuR8
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    lens-4.17-5x7O0MbP3WCHzFU8I87c33
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-time-0.3.1.0-9WsuLBKAlPL3yTdJ9sJWEr mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    quickcheck-instances-0.3.19-DkbwbtagYhbDo5fzLZ5DV1
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    x509-1.7.5-HSY0xPcI4REFeHDt27wwza
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.7.0.0-83-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-9Fk7PayTpKr8psGDeQfjn7
key: jose-0.7.0.0-9Fk7PayTpKr8psGDeQfjn7
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: f25b8823a22211b0517e1906d081d083
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.6.4/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-9Fk7PayTpKr8psGDeQfjn7
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-3Fy8y4TZyLW38WYgCKr7yc
    attoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    bytestring-0.10.8.2 concise-0.1.0.1-Jx5AGKVeUlp3H0I6pPwT6X
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    lens-4.17-9007cpgFhetJxFTlfQo2qw
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-time-0.3.1.0-9WsuLBKAlPL3yTdJ9sJWEr mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    quickcheck-instances-0.3.19-FWgxOqx5GAYKN6OtlKu69p
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    x509-1.7.5-4UJhh5NPMuwB64nGGQQFaV
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
